@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: CommandLine.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *	This object manages the command line widget
  *
@@ -29,7 +29,7 @@
 
 #include "HerculesStudio.h"
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 #include <QLineEdit>
 
 class CommandLine : public QLineEdit
@@ -40,7 +40,10 @@ public:
   virtual ~CommandLine();
   void setFont();
   bool empty();
+  void save();
+  void restore();
 
+  using QLineEdit::sizeHint;
   QSize sizeHint();
 
 protected:
@@ -49,8 +52,11 @@ protected:
 private slots:
     void enterPressed(const QString & text);
 
+signals:
+    void ctrl_c();
+
 private:
-  std::vector<std::string> mHistory;
+  QVector<QString> mHistory;
   int mHistoryPtr;
 
   void setLine();
