@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: DasdLoad.h 114 2011-03-02 19:35:46Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *	Dasdload utility object
  *
@@ -27,11 +27,13 @@
 #ifndef DASDLOAD_H
 #define DASDLOAD_H
 
-#include <QtGui/QDialog>
+#include "GenericUtility.h"
+
+#include <QtWidgets/QDialog>
 #include "ui_DasdLoad.h"
 
 class UtilityExecutor;
-class DasdLoad : public QDialog
+class DasdLoad : public GenericUtility
 {
     Q_OBJECT
 
@@ -42,7 +44,9 @@ public:
 private:
     Ui::DasdLoadClass ui;
     bool              mEnded;
-    UtilityExecutor * mExecutor;
+
+private:
+    void finishedSlot();
 
 private slots:
     void exitClicked();
