@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: Dasdconv.h 93 2011-01-14 06:34:16Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *	Dasdconv utility object
  *
@@ -29,7 +29,7 @@
 
 #include "GenericUtility.h"
 
-#include <QtGui/QDialog>
+#include <QtWidgets/QDialog>
 #include "ui_Dasdconv.h"
 
 class UtilityExecutor;
