@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: HelpAbout.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #ifndef HELPABOUT_H
 #define HELPABOUT_H
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 #include "ui_helpabout.h"
 
 class HelpAbout : public QDialog
