@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Sep 3, 2010
  *
- *  Copyright (c) 2009-2010 Jacob Dekel
- *  $Id: HetGet.h 90 2011-01-12 07:32:12Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *  Hetget utility object
  *
@@ -29,7 +29,7 @@
 
 #include "GenericUtility.h"
 
-#include <QtGui/QDialog>
+#include <QtWidgets/QDialog>
 #include "ui_HetGet.h"
 
 class HetGet : public GenericUtility
