@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Sep 6, 2010
  *
- *  Copyright (c) 2009-2010 Jacob Dekel
- *  $Id: HetMap.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *  Hetmap utility object
  *
@@ -29,7 +29,7 @@
 
 #include "GenericUtility.h"
 
-#include <QtGui/QDialog>
+#include <QtWidgets/QDialog>
 #include "ui_HetMap.h"
 
 class HetMap : public GenericUtility
@@ -55,6 +55,7 @@ private slots:
 	void dataInfoClicked();
 	void tapemapClicked();
 	void browseFileClicked();
+	void runnerError(const QByteArray &line);
 };
 
 #endif // HETMAP_H
