@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Sep 3, 2010
  *
- *  Copyright (c) 2009-2010 Jacob Dekel
- *  $Id: HetUpd.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *  Hetupd utility object
  *
@@ -29,7 +29,7 @@
 
 #include "GenericUtility.h"
 
-#include <QtGui/QDialog>
+#include <QtWidgets/QDialog>
 #include "ui_HetUpd.h"
 
 class HetUpd : public GenericUtility
