@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: MainWindow.cpp 130 2011-06-17 08:26:20Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,6 +43,10 @@
 #include "HetGet.h"
 #include "HetUpd.h"
 #include "HetMap.h"
+#include "PrinterDialog.h"
+#include "StationeryDialog.h"
+#include "StationeryDialog.h"
+#include "DecolationDialog.h"
 #include "NamedPipe.h"
 #include "Environment.h"
 #include "Arguments.h"
@@ -62,6 +66,10 @@
 #include <err.h>
 #endif
 #include <typeinfo>
+#ifdef UNISTD_INC
+#include <unistd.h>
+#endif
+
 
 MainWindow::MainWindow(QWidget *parent)
 	: QMainWindow(parent),
@@ -70,19 +78,13 @@ MainWindow::MainWindow(QWidget *parent)
 	mConfigFile(NULL),
 	mCommandLine(NULL),
 	mHerculesExecutor(NULL),
-	mPreferences(NULL),
-	mHerculesActive(false)
+    mPrinterDialog(NULL),
+    mHerculesActive(false)
 {
 	ui.setupUi(this);
+	setDarkBackground(Preferences::getInstance().darkBackground());
 	QString iconPath(Environment::getIconsPath().c_str());
 	this->setWindowIcon(QIcon(iconPath+"/tray.xpm"));
-	ui.actionTapecopy->setVisible(true);
-	ui.actionTapemap->setVisible(true);
-	ui.actionTapesplit->setVisible(true);
-	ui.actionHetget->setVisible(true);
-	ui.actionHetinit->setVisible(true);
-	ui.actionHetmap->setVisible(true);
-	ui.actionHetupd->setVisible(true);
 
 	if (Arguments::getInstance().configFileName().length() > 0)
 	{
@@ -207,10 +209,15 @@ MainWindow::MainWindow(QWidget *parent)
 	editViewPSW();
 
 	QString path = Environment::getIconsPath().c_str();
-	outDebug(3,std::cout << "icons=" << path.toStdString() << std::endl);
 	QIcon trayIcon(path + "/tray.xpm");
 	mSystemTrayIcon = new QSystemTrayIcon(trayIcon);
 
+    QMenu *trayIconMenu = new QMenu(this);
+    QAction *restoreAction = new QAction(tr("&Hide"), this);
+    connect(restoreAction, SIGNAL(triggered()), this, SLOT(hideRestore()));
+    trayIconMenu->addAction(restoreAction);
+    mSystemTrayIcon->setContextMenu(trayIconMenu);
+
 	connect(ui.actionNew, SIGNAL(triggered()), this , SLOT(newConfig()));
 	connect(ui.actionOpen_configuration, SIGNAL(triggered()), this , SLOT(openConfig()));
 	connect(ui.actionEditConfig, SIGNAL(triggered()), this , SLOT(config()));
@@ -227,7 +234,8 @@ MainWindow::MainWindow(QWidget *parent)
 	connect(ui.actionView_64_bit_General_Registers, SIGNAL(triggered()), this, SLOT(editView64BitGr()));
 	connect(ui.actionView_64_bit_Control_Registers, SIGNAL(triggered()), this, SLOT(editView64BitCr()));
 	connect(ui.actionView_64_bit_Floating_Point_Registers, SIGNAL(triggered()), this, SLOT(editView64BitFr()));
-	connect(ui.actionView_PSW, SIGNAL(triggered()), this, SLOT(editViewPSW()));
+    connect(ui.actionView_PSW, SIGNAL(triggered()), this, SLOT(editViewPSW()));
+    connect(ui.actionCopy, SIGNAL(triggered()), this, SLOT(editCopy()));
 	connect(ui.actionDelete_messages, SIGNAL(triggered()), this, SLOT(deleteMessages()));
 	connect(ui.actionSave_messages, SIGNAL(triggered()), this, SLOT(saveMessages()));
 	connect(ui.actionPreferences, SIGNAL(triggered()), this, SLOT(preferences()));
@@ -254,11 +262,15 @@ MainWindow::MainWindow(QWidget *parent)
 	connect(ui.actionHetget, SIGNAL(triggered()), this, SLOT(hetget()));
 	connect(ui.actionHetupd, SIGNAL(triggered()), this, SLOT(hetupd()));
 	connect(ui.actionHetmap, SIGNAL(triggered()), this, SLOT(hetmap()));
-	connect(ui.actionAbout, SIGNAL(triggered()), this, SLOT(helpAbout()));
+    connect(ui.actionStartPrinter, SIGNAL(triggered()), this, SLOT(printer()));
+    connect(ui.actionStationery, SIGNAL(triggered()), this, SLOT(stationery()));
+    connect(ui.actionDecolation, SIGNAL(triggered()), this, SLOT(decolation()));
+    connect(ui.actionAbout, SIGNAL(triggered()), this, SLOT(helpAbout()));
 	connect(mDevicesPane, SIGNAL(restartDevices()), this , SLOT(restartDevices()));
 	connect(mCommandLine, SIGNAL(returnPressed()), this , SLOT(newCommand()));
+    connect(mCommandLine, SIGNAL(ctrl_c()), this , SLOT(editCopy()));
 	connect(mSystemTrayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), this, SLOT(systrayClick(QSystemTrayIcon::ActivationReason)));
-	connectMainPanel();
+    connectMainPanel();
 
 	if (Preferences::getInstance().splitLog())
 	{
@@ -293,12 +305,19 @@ MainWindow::MainWindow(QWidget *parent)
 			mLogWindow->append("--- successfully attached to Hercules ---");
 		}
 	}
+    mCommandLine->restore();
+	setVisible(true);
+	if (Preferences::getInstance().animate())
+        QTimer::singleShot(100, this, SLOT(preferencesChanged()));
 	if (Arguments::getInstance().configFileName().length() > 0)
 		powerOn();
 }
 
 MainWindow::~MainWindow()
 {
+	DeviceConfigLine::clear();  // free acquired static data
+	if (mConfigFile != NULL)
+		delete mConfigFile;
 }
 
 void MainWindow::connectMainPanel()
@@ -323,6 +342,7 @@ void MainWindow::preferencesChanged()
 	fontChanged();
 	mipsChanged();
 	pswChanged();
+	styleChanged();
 	themeChanged();
 	mLogWindow->preferencesChanged();
 }
@@ -330,7 +350,7 @@ void MainWindow::preferencesChanged()
 void MainWindow::fontChanged()
 {
 	std::string fontName = Preferences::getInstance().fontName(Preferences::LogFontObject);
-	if (fontName[0] == '(')
+    if (fontName.size() == 0 || fontName[0] == '(')
 	{
 		mLogWindow ->setFont(QFont());
 	}
@@ -361,11 +381,11 @@ void MainWindow::mipsChanged()
 
 void MainWindow::pswChanged()
 {
-	mPsw->setMode(mPreferences->pswMode());
-	mPswDock->setVisible(mPreferences->pswMode() == Psw::Docked);
+    mPsw->setMode(Preferences::getInstance().pswMode());
+    mPswDock->setVisible(Preferences::getInstance().pswMode() == Psw::Docked);
 }
 
-void MainWindow::themeChanged()
+void MainWindow::styleChanged()
 {
 	QByteArray loadAddress =
 			QByteArray::number(mMainPanel->getLoadAddress(),16); // preserve
@@ -378,7 +398,14 @@ void MainWindow::themeChanged()
 	mMainPanel->setLoadAddress(loadAddress);	// restore ipl address
 	if (mHerculesActive) mMainPanel->standby();
 	mTopDock->setWidget(mMainPanel);
-	connectMainPanel();
+    connectMainPanel();
+}
+
+void MainWindow::themeChanged()
+{
+	setDarkBackground (Preferences::getInstance().darkBackground());
+    if (Preferences::getInstance().animate())
+		mMainPanel->animate();
 }
 
 void MainWindow::writeToLogFromQueue()
@@ -437,7 +464,8 @@ void MainWindow::dispatchStatus()
 
 void MainWindow::recoverDevices(QByteArray& statusLine)
 {
-	if (statusLine.left(5) == "DEVX=") return;
+	hOutDebug(3,"recorver:" <<statusLine.data());
+	if (statusLine.startsWith("DEVX=")) return;
 	if (statusLine[4] == 'X')
 	{
 		if ( mDevicesRecoveryCommenced )
@@ -451,7 +479,11 @@ void MainWindow::recoverDevices(QByteArray& statusLine)
 		}
 		return;
 	}
-	statusLine = "DEVA=" + statusLine.mid(4);
+	else if (statusLine.startsWith("DEV="))
+		statusLine = "DEVA=" + statusLine.mid(4);
+	else  if (statusLine.startsWith("DEV") && statusLine[4] == '=')
+		statusLine = "DEVA=" + statusLine.mid(5);
+
 }
 
 void MainWindow::newCommand()
@@ -459,18 +491,17 @@ void MainWindow::newCommand()
 	if (mHerculesExecutor == NULL) return;
 	CommandLine *cl = static_cast<CommandLine *>(QObject::sender());
 	if (cl == NULL) return;
-	outDebug(2, std::cout  << cl->text().toStdString() << std::endl);
+    hOutDebug(2, cl->text().toStdString());
 	if (!mLogWindow->isOSLog() || cl->text().left(1).compare(".") == 0)
-		mHerculesExecutor->issueFormattedCommand("%s\n",cl->text().toAscii().data());
+		mHerculesExecutor->issueFormattedCommand("%s\n",cl->text().toUtf8().data());
 	else
-		mHerculesExecutor->issueFormattedCommand(".%s\n",cl->text().toAscii().data());
+		mHerculesExecutor->issueFormattedCommand(".%s\n",cl->text().toUtf8().data());
+    setIpled(cl->text());
 }
 
 
 void MainWindow::newConfig()
 {
-	if (mPreferences == NULL)
-		mPreferences = &Preferences::getInstance();
 	mConfigFile = new ConfigFile("/usr/share/herculesstudio/template.conf");
 	mConfigFile->setNew(true);
 	mConfiguration = new Configuration(mConfigFile, true, this);
@@ -490,19 +521,17 @@ void MainWindow::config()
 
 void MainWindow::openConfig()
 {
-	if (mPreferences == NULL)
-			mPreferences = &Preferences::getInstance();
-	outDebug(5,std::cout << "config at:" << mPreferences->configDir() << std::endl);
+    hOutDebug(5,"config at:" << Preferences::getInstance().configDir() << ".");
 	std::string s = QFileDialog::getOpenFileName(this,
-			"Open configuration",
-			mPreferences->configDir().c_str(),
+            tr("Open configuration"),
+            Preferences::getInstance().configDir().c_str(),
 			tr("Hercules configuration files (*.conf *.cnf);;All files(*)")).toUtf8().data();
 	if (s.length() == 0)
 		return;
 
 	mConfigFile = new ConfigFile(s);
 	QFileInfo f(s.c_str());
-	mPreferences->setVolatileConfigDir(f.dir().absolutePath().toStdString().c_str());
+    Preferences::getInstance().setVolatileConfigDir(f.dir().absolutePath().toStdString().c_str());
 	this->setWindowTitle((mConfigFile->getFileName() + " - Hercules Studio").c_str());
 }
 
@@ -523,10 +552,8 @@ void MainWindow::saveConfig()
 void MainWindow::saveConfigAs()
 {
 	if (mConfigFile == NULL) return;
-	if (mPreferences == NULL)
-			mPreferences = &Preferences::getInstance();
 
-	if (mConfigFile->isNew())
+    if (mConfigFile->isNew())
 	{
 		if (mConfigFile->numberOfDevices() == 0)
 		{
@@ -547,7 +574,7 @@ void MainWindow::saveConfigAs()
 
 	std::string s = QFileDialog::getSaveFileName(this,
 			"Save configuration",
-			mPreferences->configDir().c_str(),
+            Preferences::getInstance().configDir().c_str(),
 			tr("Hercules configuration files (*.conf *.cnf);;All files(*)")).toUtf8().data();
 	if (s.length() == 0)
 		return;
@@ -655,7 +682,17 @@ void MainWindow::editViewPSW()
 	{
 		mPswDock->setVisible(newVal);
 	}
- }
+}
+
+void MainWindow::editCopy()
+{
+    hOutDebug(4, "COPY");
+
+    if (mLogWindow->textIsSelected())
+    {
+        mLogWindow->copySelectedText();
+    }
+}
 
 void MainWindow::deleteMessages()
 {
@@ -677,16 +714,14 @@ void MainWindow::deleteMessages()
 
 void MainWindow::saveMessages()
 {
-	mLogWindow->writeToFile(true);
+	mLogWindow->writeToFile(PlainLogWidget::MenuCommand);
 	return;
 }
 
 void MainWindow::preferences()
 {
-	if (mPreferences == NULL)
-		mPreferences = &Preferences::getInstance();
-	PreferencesWin * pw = new PreferencesWin(mCurrentPath.toStdString(), mPreferences, this);
-	connect(pw, SIGNAL(preferencesChanged()), this, SLOT(preferencesChanged()));
+    PreferencesWin * pw = new PreferencesWin(mCurrentPath.toStdString(), this);
+    connect(pw, SIGNAL(preferencesChanged()), this, SLOT(preferencesChanged()));
 	pw->exec();
 }
 
@@ -705,7 +740,6 @@ void MainWindow::powerOn()
 		if (mConfigFile == NULL) openConfig();
 		if (mConfigFile == NULL) return;
 		configName = mConfigFile->getFileName();
-		mPreferences = &Preferences::getInstance();
 	}
 	else
 	{
@@ -735,14 +769,14 @@ void MainWindow::powerOn()
 	int herculesPid = 0;
 	if (!mRecovery)
 	{
-		outDebug(5,std::cout << "not recovery" << std::endl);
+        hOutDebug(5,"not recovery");
 		mHerculesExecutor = new HerculesExecutor(*this);
-		herculesPid = mHerculesExecutor->run(configName, mPreferences->hercDir());
+        herculesPid = mHerculesExecutor->run(configName, Preferences::getInstance().hercDir());
 		mDevicesRecovery = false;
 	}
 	else
 	{
-		outDebug(2,std::cout << "recovery" << std::endl);
+        hOutDebug(2,"recovery");
 		herculesPid = NamedPipe::getInstance().getHerculesPid();
 		mHerculesExecutor = new HerculesExecutor(*this, herculesPid);
 		mDevicesRecovery = true;
@@ -765,11 +799,11 @@ void MainWindow::powerOn()
 #endif
 
 	mLogRunner = new LogRunner(mLogQueue, mHerculesExecutor, Preferences::getInstance().logFileLines());
-	connect(mLogRunner, SIGNAL(newData()), this , SLOT(writeToLogFromQueue()));
+    connect(mLogRunner, SIGNAL(newData()), this , SLOT(writeToLogFromQueue()));
 	mLogRunner->start();
 
 	mStatusRunner = new StatusRunner(mStatusQueue, mHerculesExecutor);
-	connect(mStatusRunner, SIGNAL(newData()), this , SLOT(dispatchStatus()));
+    connect(mStatusRunner, SIGNAL(newData()), this , SLOT(dispatchStatus()));
 	mStatusRunner->start();
 
 #ifndef hFramework
@@ -777,7 +811,7 @@ void MainWindow::powerOn()
 #else
 	mWatchdog = new Watchdog(mHerculesExecutor->getQProcess());
 #endif
-	connect(mWatchdog, SIGNAL(HerculesEnded()), this, SLOT(herculesEndedSlot()));
+    connect(mWatchdog, SIGNAL(HerculesEnded()), this, SLOT(herculesEndedSlot()));
 	mWatchdog->start();
 
 	mHerculesActive = true;
@@ -826,8 +860,9 @@ void MainWindow::powerOff()
 	usleep(100000);  // TODO32
 	#endif
 	mDevicesPane->clear();
-	mMainPanel->setDormant();
+//	mMainPanel->setDormant();
 	mPsw->setDormant();
+    mCommandLine->save();
 }
 
 void MainWindow::load()
@@ -839,7 +874,7 @@ void MainWindow::load()
 		return;
 	}
 	int addr = mMainPanel->getLoadAddress();
-	outDebug(1, std::cout << "going to load " << addr << std::endl);
+    hOutDebug(1, "going to load " << addr);
 	mHerculesExecutor->issueFormattedCommand("IPL %X\n",addr);
 	mIplDevno.setNum(addr,16);
 	mLogWindow->setIpled(true);
@@ -886,7 +921,7 @@ void MainWindow::loadCommand()
 void MainWindow::extInterrupt()
 {
 	if (!mHerculesActive) return;
-	outDebug(1, std::cout << "going to externally interrupt " << std::endl);
+    hOutDebug(1, "going to externally interrupt ");
 	mHerculesExecutor->issueCommand("ext\n");
 	return;
 }
@@ -895,7 +930,7 @@ void MainWindow::devInterrupt()
 {
 	if (!mHerculesActive) return;
 	int addr = mMainPanel->getLoadAddress();
-	outDebug(1, std::cout << "going to interrupt " << addr << std::endl);
+    hOutDebug(1, "going to interrupt " << addr);
 	mHerculesExecutor->issueFormattedCommand("I %X\n", addr);
 }
 
@@ -1026,13 +1061,41 @@ void MainWindow::hetmap()
 	hetmap->exec();
 }
 
+void MainWindow::printer()
+{
+    if (mPrinterDialog == NULL)
+        mPrinterDialog = new PrinterDialog(0);
+    mPrinterDialog->show();
+    connect(mPrinterDialog, SIGNAL(destroyed()), this, SLOT(printerFinished()));
+}
+
+void MainWindow::printerFinished()
+{
+    mPrinterDialog = NULL;
+}
+
+void MainWindow::stationery()
+{
+    StationeryDialog* stationeryDialog = new StationeryDialog(this);
+    stationeryDialog->exec();
+}
+
+void MainWindow::decolation()
+{
+    DecolationDialog* dialog = new DecolationDialog(this);
+    dialog->exec();
+}
+
 void MainWindow::herculesEndedSlot()
 {
 	std::cerr << "############ ended ##############" << std::endl;
 	mLogWindow->setIpled(false);
+	mLogWindow->writeToFile(PlainLogWidget::Shutdown);
 	mLogRunner->terminate();
 	mStatusRunner->terminate();
 	mWatchdog->terminate();
+	if (mWatchdog != NULL) delete mWatchdog;
+	mWatchdog = NULL;
 	mHerculesActive = false;
 	mCommandLine->setReadOnly(true);
 	mHerculesExecutor = NULL;
@@ -1055,7 +1118,7 @@ void MainWindow::systrayHint()
 {
 	if (!mSystrayHintEjected)
 	{
-		mSystemTrayIcon->showMessage("Hercules is still active","Click this icon to restore the main window",QSystemTrayIcon::Information,5000);
+        mSystemTrayIcon->showMessage("Hercules is still active","Click the Hercules icon to restore the main window",QSystemTrayIcon::Information,5000);
 		mSystemTrayIcon->setToolTip("Click on this icon to restore the main window");
 		mSystrayHintEjected = true;
 	}
@@ -1069,12 +1132,14 @@ void MainWindow::closeEvent(QCloseEvent *event)
 		 mSystemTrayIcon->setVisible(true);
 		 systrayHint();
 		 setVisible(false);
+         mSystemTrayIcon->contextMenu()->actions().at(0)->setText("&Restore");
 
-		 event->ignore();
+         event->ignore();
 	 }
 	 else
 	 {
 		 hOutDebug(5,"Close");
+
 		 if (mHerculesActive)
 		 {
 			 if( QMessageBox::warning(this,"Hercules Is Still Running",
@@ -1088,6 +1153,31 @@ void MainWindow::closeEvent(QCloseEvent *event)
 			 }
 			 else hOutDebug(5,"abort");
 		 }
+
+         if (mPrinterDialog != NULL)
+         {
+             if (mPrinterDialog->isConnected())
+             {
+                 if( QMessageBox::warning(this,"Printer Is Still Connected",
+                                          "Press Close - To Close The Printer\n"
+                                          "Or\n"
+                                          "Press Cancel - To Return",
+                                          QMessageBox::Cancel, QMessageBox::Close) == QMessageBox::Cancel)
+                 {
+                     event->ignore();
+                 }
+                 else
+                 {
+                     mPrinterDialog->close();
+                     delete mPrinterDialog;
+                 }
+             }
+             else
+             {
+                 mPrinterDialog->close();
+                 delete mPrinterDialog;
+             }
+         }
 	 }
  }
 
@@ -1100,15 +1190,31 @@ void MainWindow::tryAbort()
 
 void MainWindow::systrayClick(QSystemTrayIcon::ActivationReason)
 {
-	if (isVisible())
+    hideRestore();
+}
+
+void MainWindow::hideRestore()
+{
+    if (isVisible())
 	{
 		setVisible(false);
 		systrayHint();
+        mSystemTrayIcon->contextMenu()->actions().at(0)->setText("Restore");
+
 	}
 	else
 	{
 		setVisible(true);
-	}
+        mSystemTrayIcon->contextMenu()->actions().at(0)->setText("Hide");
+    }
+}
+
+void MainWindow::keyPressEvent(QKeyEvent * event)
+{
+    hOutDebug(4,"key:" << event->key() << " " << (event->key() == Qt::Key_Up));
+	QMainWindow::keyPressEvent(event);
+	if (!mCommandLine->hasFocus())
+		mCommandLine->setFocus();
 }
 
 void MainWindow::restartDevices()
@@ -1124,9 +1230,14 @@ void MainWindow::restartDevices()
 
 bool MainWindow::issueCommand(const std::string& command)
 {
-   if (mHerculesActive)
-		mHerculesExecutor->issueFormattedCommand("%s\n", command.c_str());
-	outDebug(2, std::cout << "issue command:" << command << std::endl);
+    QString qCommand  = command.c_str();
+    if (mHerculesActive)
+    {
+        mHerculesExecutor->issueFormattedCommand("%s\n", command.c_str());
+        setIpled(qCommand);
+    }
+
+    hOutDebug(2,"issue command:" << command);
    return true;
 }
 
@@ -1141,3 +1252,33 @@ void MainWindow::testGui()
 			 QMessageBox::Ok);
 	}
 }
+
+void MainWindow::setIpled(QString command)
+{
+    if (mHerculesActive)
+    {
+         if (command.toLower().leftJustified(4).startsWith("ipl "))
+         {
+             mLogWindow->setIpled(true);
+         }
+         else if (command.toLower().leftJustified(5).startsWith("quit "))
+         {
+             mLogWindow->setIpled(false);
+         }
+
+    }
+}
+
+void MainWindow::setDarkBackground(bool dark)
+{
+	if (dark)
+	{
+        QFile file(":/icons/darkorange.css");
+		if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+				 return;
+		QByteArray ss = file.readAll();
+		setStyleSheet(ss);
+	}
+	else
+		setStyleSheet("");
+}
