@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: Mips.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *	This object presents the current mips reading as received from hercules
  *
@@ -36,7 +36,7 @@ public:
     virtual ~Mips();
 
     virtual void display(double value) = 0;
-    virtual void setVisible(bool) = 0;
+	virtual void setActive(bool) = 0;
     virtual void move(int, int) = 0;
     virtual void setToolTip(const QString &) = 0;
     virtual void deleteLater(void) = 0;
