@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: June 15, 2010
  *
- *  Copyright (c) 2009-2010 Jacob Dekel
- *  $Id: MipsGauge.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *	This object presents the current mips reading as gauge needle
  *
@@ -38,7 +38,7 @@ public:
 	virtual ~MipsGauge();
 
     virtual void display(double);
-    virtual void setVisible(bool visible);
+	virtual void setActive(bool visible);
     virtual void move(int, int);
     virtual void setToolTip(const QString & tip);
     virtual void deleteLater(void);
@@ -46,11 +46,12 @@ public:
 
 protected:
     void paintEvent(QPaintEvent *);
+	double  mPrevAngle;
 
 private:
-    QWidget * mMips;
     double mValue;
     double mHwm;
+	QColor mPenColor;
 };
 
 #endif /* MIPSGAUGE_H_ */
