@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: June 15, 2010
  *
- *  Copyright (c) 2009-2010 Jacob Dekel
- *  $Id: MipsLed.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *	This object presents the current mips reading in LCD format
  *
@@ -39,7 +39,7 @@ public:
     virtual ~MipsLed();
 
     virtual void display(double);
-    virtual void setVisible(bool visible);
+	virtual void setActive(bool active);
     virtual void move(int, int);
     virtual void setToolTip(const QString & tip);
     virtual void deleteLater(void);
