@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: Recovery.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *	This object is called when we need the user's configmation to re-attach
  *	To hercules
@@ -28,7 +28,7 @@
 #ifndef RECOVERY_H
 #define RECOVERY_H
 
-#include <QtGui/QDialog>
+#include <QtWidgets/QDialog>
 #include "ui_Recovery.h"
 
 class Recovery : public QDialog
