@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: SysgProperties.cpp 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ SysgProperties::SysgProperties(ConfigLine& line, QWidget *parent)
 {
     getUi().terminalCombo->clear();
     getUi().terminalCombo->insertItems(0, QStringList()
-     << QApplication::translate("TerminalPropertiesClass", "SYSG", 0, QApplication::UnicodeUTF8)
+     << QApplication::translate("TerminalPropertiesClass", "SYSG", 0)
     );
     getUi().terminalCombo->setEnabled(false);
     getUi().deviceNumber->setText("0000");
