@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 27, 2010
  *
- *  Copyright (c) 2009-2010 Jacob Dekel
- *  $Id: TapeCopy.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *  tapecopy utility object
  *
@@ -28,7 +28,7 @@
 
 #include "GenericUtility.h"
 
-#include <QtGui/QDialog>
+#include <QtWidgets/QDialog>
 #include "ui_TapeCopy.h"
 
 class TapeCopy : public GenericUtility
