@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: TapeProperties.h 67 2010-09-13 14:06:31Z dekeljacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id$
  *
  *	This object manages the tape configuration properties
  *
@@ -30,7 +30,7 @@
 #include "ConfigLine.h"
 #include "GenericDeviceProperties.h"
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 #include "ui_TapeProperties.h"
 
 class TapeProperties : public GenericDeviceProperties
